@@ -1,6 +1,5 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
-from __future__ import with_statement
 from decimal import Decimal
 import datetime
 import time
@@ -10,8 +9,9 @@ from trytond.model import ModelView, ModelSQL, fields
 from trytond.wizard import Wizard
 from trytond.report import Report
 from trytond.tools import reduce_ids
-from trytond.pyson import Equal, Eval, Not, PYSONEncoder, Date
+from trytond.pyson import Eval, PYSONEncoder, Date
 from trytond.transaction import Transaction
+from trytond.pool import Pool
 
 
 class TypeTemplate(ModelSQL, ModelView):
@@ -100,8 +100,8 @@ class TypeTemplate(ModelSQL, ModelView):
                 be created
         :return: id of the type created
         '''
-        type_obj = self.pool.get('account.account.type')
-        lang_obj = self.pool.get('ir.lang')
+        type_obj = Pool().get('account.account.type')
+        lang_obj = Pool().get('ir.lang')
 
         if template2type is None:
             template2type = {}
@@ -153,8 +153,8 @@ class Type(ModelSQL, ModelView):
     _description = __doc__
     name = fields.Char('Name', size=None, required=True, translate=True)
     parent = fields.Many2One('account.account.type', 'Parent',
-            ondelete="RESTRICT", domain=[
-                ('company', '=', Eval('company')),
+        ondelete="RESTRICT", domain=[
+            ('company', '=', Eval('context', {}).get('company')),
             ])
     childs = fields.One2Many('account.account.type', 'parent', 'Children',
         domain=[
@@ -203,8 +203,8 @@ class Type(ModelSQL, ModelView):
         return res
 
     def get_amount(self, ids, name):
-        account_obj = self.pool.get('account.account')
-        currency_obj = self.pool.get('currency.currency')
+        account_obj = Pool().get('account.account')
+        currency_obj = Pool().get('currency.currency')
 
         res = {}
         for type_id in ids:
@@ -267,8 +267,8 @@ class Type(ModelSQL, ModelView):
                 and type id as value, used to convert template id
                 into type. The dictionary is filled with new types
         '''
-        template_obj = self.pool.get('account.account.type.template')
-        lang_obj = self.pool.get('ir.lang')
+        template_obj = Pool().get('account.account.type.template')
+        lang_obj = Pool().get('ir.lang')
 
         if template2type is None:
             template2type = {}
@@ -317,17 +317,17 @@ class AccountTemplate(ModelSQL, ModelView):
             select=1)
     code = fields.Char('Code', size=None, select=1)
     type = fields.Many2One('account.account.type.template', 'Type',
-            ondelete="RESTRICT",
-            states={
-                'invisible': Equal(Eval('kind'), 'view'),
-                'required': Not(Equal(Eval('kind'), 'view')),
+        ondelete="RESTRICT",
+        states={
+            'invisible': Eval('kind') == 'view',
+            'required': Eval('kind') != 'view',
             }, depends=['kind'])
     parent = fields.Many2One('account.account.template', 'Parent', select=1,
             ondelete="RESTRICT")
     childs = fields.One2Many('account.account.template', 'parent', 'Children')
     reconcile = fields.Boolean('Reconcile',
-            states={
-                'invisible': Equal(Eval('kind'), 'view'),
+        states={
+            'invisible': Eval('kind') == 'view',
             }, depends=['kind'])
     kind = fields.Selection([
         ('other', 'Other'),
@@ -338,8 +338,8 @@ class AccountTemplate(ModelSQL, ModelView):
         ('view', 'View'),
         ], 'Kind', required=True)
     deferral = fields.Boolean('Deferral', states={
-        'invisible': Equal(Eval('kind'), 'view'),
-        }, depends=['kind'])
+            'invisible': Eval('kind') == 'view',
+            }, depends=['kind'])
 
     def __init__(self):
         super(AccountTemplate, self).__init__()
@@ -374,11 +374,11 @@ class AccountTemplate(ModelSQL, ModelView):
 
     def search_rec_name(self, name, clause):
         ids = self.search([
-            ('code',) + tuple(clause[1:]),
+            ('code',) + clause[1:],
             ], limit=1)
         if ids:
-            return [('code',) + tuple(clause[1:])]
-        return [(self._rec_name,) + tuple(clause[1:])]
+            return [('code',) + clause[1:]]
+        return [(self._rec_name,) + clause[1:]]
 
     def _get_account_value(self, template, account=None):
         '''
@@ -422,8 +422,8 @@ class AccountTemplate(ModelSQL, ModelView):
                 that must be created
         :return: id of the account created
         '''
-        account_obj = self.pool.get('account.account')
-        lang_obj = self.pool.get('ir.lang')
+        account_obj = Pool().get('account.account')
+        lang_obj = Pool().get('ir.lang')
 
         if template2account is None:
             template2account = {}
@@ -487,7 +487,7 @@ class AccountTemplate(ModelSQL, ModelView):
         :param template_done: a list of template id already updated.
             The list is filled.
         '''
-        account_obj = self.pool.get('account.account')
+        account_obj = Pool().get('account.account')
 
         if template2account is None:
             template2account = {}
@@ -533,11 +533,12 @@ class Account(ModelSQL, ModelView):
             help='Force all moves for this account \n' \
                     'to have this secondary currency.', ondelete="RESTRICT")
     type = fields.Many2One('account.account.type', 'Type', ondelete="RESTRICT",
-            states={
-                'invisible': Equal(Eval('kind'), 'view'),
-                'required': Not(Equal(Eval('kind'), 'view')),
-            }, domain=[
-                ('company', '=', Eval('company')),
+        states={
+            'invisible': Eval('kind') == 'view',
+            'required': Eval('kind') != 'view',
+            },
+        domain=[
+            ('company', '=', Eval('company')),
             ], depends=['kind', 'company'])
     parent = fields.Many2One('account.account', 'Parent', select=1,
             left="left", right="right", ondelete="RESTRICT")
@@ -554,10 +555,10 @@ class Account(ModelSQL, ModelView):
         digits=(16, Eval('currency_digits', 2)), depends=['currency_digits']),
         'get_credit_debit')
     reconcile = fields.Boolean('Reconcile',
-            help='Allow move lines of this account \n' \
-                    'to be reconciled.',
-            states={
-                'invisible': Equal(Eval('kind'), 'view'),
+        help='Allow move lines of this account \n' \
+            'to be reconciled.',
+        states={
+            'invisible': Eval('kind') == 'view',
             }, depends=['kind'])
     note = fields.Text('Note')
     kind = fields.Selection([
@@ -569,11 +570,11 @@ class Account(ModelSQL, ModelView):
         ('view', 'View'),
         ], 'Kind', required=True)
     deferral = fields.Boolean('Deferral', states={
-        'invisible': Equal(Eval('kind'), 'view'),
-        }, depends=['kind'])
+            'invisible': Eval('kind') == 'view',
+            }, depends=['kind'])
     deferrals = fields.One2Many('account.account.deferral', 'account',
-            'Deferrals', readonly=True, states={
-                'invisible': Equal(Eval('kind'), 'view'),
+        'Deferrals', readonly=True, states={
+            'invisible': Eval('kind') == 'view',
             }, depends=['kind'])
     template = fields.Many2One('account.account.template', 'Template')
 
@@ -616,7 +617,7 @@ class Account(ModelSQL, ModelView):
         return 'view'
 
     def get_currency(self, ids, name):
-        currency_obj = self.pool.get('currency.currency')
+        currency_obj = Pool().get('currency.currency')
         res = {}
         for account in self.browse(ids):
             res[account.id] = account.company.currency.id
@@ -630,11 +631,12 @@ class Account(ModelSQL, ModelView):
 
     def get_balance(self, ids, name):
         res = {}
-        company_obj = self.pool.get('company.company')
-        currency_obj = self.pool.get('currency.currency')
-        move_line_obj = self.pool.get('account.move.line')
-        fiscalyear_obj = self.pool.get('account.fiscalyear')
-        deferral_obj = self.pool.get('account.account.deferral')
+        pool = Pool()
+        company_obj = pool.get('company.company')
+        currency_obj = pool.get('currency.currency')
+        move_line_obj = pool.get('account.move.line')
+        fiscalyear_obj = pool.get('account.fiscalyear')
+        deferral_obj = pool.get('account.account.deferral')
         cursor = Transaction().cursor
 
         query_ids, args_ids = self.search([
@@ -734,11 +736,12 @@ class Account(ModelSQL, ModelView):
             a dictionary as value with id as key
         '''
         res = {}
-        move_line_obj = self.pool.get('account.move.line')
-        company_obj = self.pool.get('company.company')
-        currency_obj = self.pool.get('currency.currency')
-        fiscalyear_obj = self.pool.get('account.fiscalyear')
-        deferral_obj = self.pool.get('account.account.deferral')
+        pool = Pool()
+        move_line_obj = pool.get('account.move.line')
+        company_obj = pool.get('company.company')
+        currency_obj = pool.get('currency.currency')
+        fiscalyear_obj = pool.get('account.fiscalyear')
+        deferral_obj = pool.get('account.account.deferral')
         cursor = Transaction().cursor
 
         for name in names:
@@ -840,25 +843,24 @@ class Account(ModelSQL, ModelView):
 
     def search_rec_name(self, name, clause):
         ids = self.search([
-            ('code',) + tuple(clause[1:]),
+            ('code',) + clause[1:],
             ], limit=1)
         if ids:
-            return [('code',) + tuple(clause[1:])]
-        return [(self._rec_name,) + tuple(clause[1:])]
+            return [('code',) + clause[1:]]
+        return [(self._rec_name,) + clause[1:]]
 
     def copy(self, ids, default=None):
         if default is None:
             default = {}
         default['left'] = 0
         default['right'] = 0
-        default.setdefault('deferrals', [])
         res = super(Account, self).copy(ids, default=default)
         self._rebuild_tree('parent', False, 0)
         return res
 
     def write(self, ids, vals):
         if not vals.get('active', True):
-            move_line_obj = self.pool.get('account.move.line')
+            move_line_obj = Pool().get('account.move.line')
             account_ids = self.search([
                 ('parent', 'child_of', ids),
                 ])
@@ -870,7 +872,7 @@ class Account(ModelSQL, ModelView):
         return super(Account, self).write(ids, vals)
 
     def delete(self, ids):
-        move_line_obj = self.pool.get('account.move.line')
+        move_line_obj = Pool().get('account.move.line')
         if isinstance(ids, (int, long)):
             ids = [ids]
         account_ids = self.search([
@@ -895,8 +897,8 @@ class Account(ModelSQL, ModelView):
                 and type id as value, used to convert type template id
                 into type.
         '''
-        template_obj = self.pool.get('account.account.template')
-        lang_obj = self.pool.get('ir.lang')
+        template_obj = Pool().get('account.account.template')
+        lang_obj = Pool().get('ir.lang')
 
         if template2account is None:
             template2account = {}
@@ -1031,8 +1033,8 @@ class AccountDeferral(ModelSQL, ModelView):
 
     def search_rec_name(self, name, clause):
         ids = self.search(['OR',
-            ('account.rec_name',) + tuple(clause[1:]),
-            ('fiscalyear.rec_name',) + tuple(clause[1:]),
+            ('account.rec_name',) + clause[1:],
+            ('fiscalyear.rec_name',) + clause[1:],
             ])
         return [('id', 'in', ids)]
 
@@ -1080,8 +1082,8 @@ class OpenChartAccount(Wizard):
     }
 
     def _action_open_chart(self, data):
-        model_data_obj = self.pool.get('ir.model.data')
-        act_window_obj = self.pool.get('ir.action.act_window')
+        model_data_obj = Pool().get('ir.model.data')
+        act_window_obj = Pool().get('ir.action.act_window')
         act_window_id = model_data_obj.get_id('account', 'act_account_tree2')
         res = act_window_obj.read(act_window_id)
         res['pyson_context'] = PYSONEncoder().encode({
@@ -1100,22 +1102,23 @@ class PrintGeneralLegderInit(ModelView):
     fiscalyear = fields.Many2One('account.fiscalyear', 'Fiscal Year',
             required=True, on_change=['fiscalyear'])
     start_period = fields.Many2One('account.period', 'Start Period',
-            domain=[
-                ('fiscalyear', '=', Eval('fiscalyear')),
-                ('start_date', '<=', (Eval('end_period'), 'start_date')),
-            ])
+        domain=[
+            ('fiscalyear', '=', Eval('fiscalyear')),
+            ('start_date', '<=', (Eval('end_period'), 'start_date')),
+            ], depends=['fiscalyear', 'end_period'])
     end_period = fields.Many2One('account.period', 'End Period',
-            domain=[
-                ('fiscalyear', '=', Eval('fiscalyear')),
-                ('start_date', '>=', (Eval('start_period'), 'start_date'))
-            ])
+        domain=[
+            ('fiscalyear', '=', Eval('fiscalyear')),
+            ('start_date', '>=', (Eval('start_period'), 'start_date'))
+            ],
+        depends=['fiscalyear', 'start_period'])
     company = fields.Many2One('company.company', 'Company', required=True)
     posted = fields.Boolean('Posted Move', help='Show only posted move')
     empty_account = fields.Boolean('Empty Account',
             help='With account without move')
 
     def default_fiscalyear(self):
-        fiscalyear_obj = self.pool.get('account.fiscalyear')
+        fiscalyear_obj = Pool().get('account.fiscalyear')
         fiscalyear_id = fiscalyear_obj.find(
                 Transaction().context.get('company', False), exception=False)
         if fiscalyear_id:
@@ -1170,9 +1173,10 @@ class GeneralLegder(Report):
     _name = 'account.account.general_ledger'
 
     def parse(self, report, objects, datas, localcontext):
-        account_obj = self.pool.get('account.account')
-        period_obj = self.pool.get('account.period')
-        company_obj = self.pool.get('company.company')
+        pool = Pool()
+        account_obj = pool.get('account.account')
+        period_obj = pool.get('account.period')
+        company_obj = pool.get('company.company')
 
         company = company_obj.browse(datas['form']['company'])
 
@@ -1249,7 +1253,7 @@ class GeneralLegder(Report):
                 localcontext)
 
     def get_lines(self, account_ids, period_ids, posted):
-        move_line_obj = self.pool.get('account.move.line')
+        move_line_obj = Pool().get('account.move.line')
         clause = [
             ('account', 'in', account_ids),
             ('period', 'in', period_ids),
@@ -1264,8 +1268,8 @@ class GeneralLegder(Report):
         return res
 
     def lines(self, account_ids, period_ids, posted):
-        move_line_obj = self.pool.get('account.move.line')
-        move_obj = self.pool.get('account.move')
+        move_line_obj = Pool().get('account.move.line')
+        move_obj = Pool().get('account.move')
         res = dict((account_id, []) for account_id in account_ids)
         account_id2lines = self.get_lines(account_ids, period_ids, posted)
 
@@ -1298,24 +1302,24 @@ class PrintTrialBalanceInit(ModelView):
             required=True, on_change=['fiscalyear'],
             depends=['start_period', 'end_period'])
     start_period = fields.Many2One('account.period', 'Start Period',
-            domain=[
-                ('fiscalyear', '=', Eval('fiscalyear')),
-                ('start_date', '<=', (Eval('end_period'), 'start_date'))
+        domain=[
+            ('fiscalyear', '=', Eval('fiscalyear')),
+            ('start_date', '<=', (Eval('end_period'), 'start_date'))
             ],
-            depends=['end_period'])
+        depends=['end_period', 'fiscalyear'])
     end_period = fields.Many2One('account.period', 'End Period',
-            domain=[
-                ('fiscalyear', '=', Eval('fiscalyear')),
-                ('start_date', '>=', (Eval('start_period'), 'start_date'))
+        domain=[
+            ('fiscalyear', '=', Eval('fiscalyear')),
+            ('start_date', '>=', (Eval('start_period'), 'start_date'))
             ],
-            depends=['start_period'])
+        depends=['start_period', 'fiscalyear'])
     company = fields.Many2One('company.company', 'Company', required=True)
     posted = fields.Boolean('Posted Move', help='Show only posted move')
     empty_account = fields.Boolean('Empty Account',
             help='With account without move')
 
     def default_fiscalyear(self):
-        fiscalyear_obj = self.pool.get('account.fiscalyear')
+        fiscalyear_obj = Pool().get('account.fiscalyear')
         fiscalyear_id = fiscalyear_obj.find(
                 Transaction().context.get('company') or False, exception=False)
         if fiscalyear_id:
@@ -1370,9 +1374,10 @@ class TrialBalance(Report):
     _name = 'account.account.trial_balance'
 
     def parse(self, report, objects, datas, localcontext):
-        account_obj = self.pool.get('account.account')
-        period_obj = self.pool.get('account.period')
-        company_obj = self.pool.get('company.company')
+        pool = Pool()
+        account_obj = pool.get('account.account')
+        period_obj = pool.get('account.period')
+        company_obj = pool.get('company.company')
 
         company = company_obj.browse(datas['form']['company'])
 
@@ -1454,7 +1459,7 @@ class OpenBalanceSheetInit(ModelView):
     posted = fields.Boolean('Posted Move', help='Show only posted move')
 
     def default_date(self):
-        date_obj = self.pool.get('ir.date')
+        date_obj = Pool().get('ir.date')
         return date_obj.today()
 
     def default_company(self):
@@ -1490,10 +1495,11 @@ class OpenBalanceSheet(Wizard):
     }
 
     def _action_open(self, datas):
-        model_data_obj = self.pool.get('ir.model.data')
-        act_window_obj = self.pool.get('ir.action.act_window')
-        company_obj = self.pool.get('company.company')
-        lang_obj = self.pool.get('ir.lang')
+        pool = Pool()
+        model_data_obj = pool.get('ir.model.data')
+        act_window_obj = pool.get('ir.action.act_window')
+        company_obj = pool.get('company.company')
+        lang_obj = pool.get('ir.lang')
 
         company = company_obj.browse(datas['form']['company'])
         for code in [Transaction().language, 'en_US']:
@@ -1530,22 +1536,22 @@ class OpenIncomeStatementInit(ModelView):
             required=True, on_change=['fiscalyear'],
             depends=['start_period', 'end_period'])
     start_period = fields.Many2One('account.period', 'Start Period',
-            domain=[
-                ('fiscalyear', '=', Eval('fiscalyear')),
-                ('start_date', '<=', (Eval('end_period'), 'start_date'))
+        domain=[
+            ('fiscalyear', '=', Eval('fiscalyear')),
+            ('start_date', '<=', (Eval('end_period'), 'start_date'))
             ],
-            depends=['end_period'])
+        depends=['end_period', 'fiscalyear'])
     end_period = fields.Many2One('account.period', 'End Period',
-            domain=[
-                ('fiscalyear', '=', Eval('fiscalyear')),
-                ('start_date', '>=', (Eval('start_period'), 'start_date')),
+        domain=[
+            ('fiscalyear', '=', Eval('fiscalyear')),
+            ('start_date', '>=', (Eval('start_period'), 'start_date')),
             ],
-            depends=['start_period'])
+        depends=['start_period', 'fiscalyear'])
     company = fields.Many2One('company.company', 'Company', required=True)
     posted = fields.Boolean('Posted Move', help='Show only posted move')
 
     def default_fiscalyear(self):
-        fiscalyear_obj = self.pool.get('account.fiscalyear')
+        fiscalyear_obj = Pool().get('account.fiscalyear')
         fiscalyear_id = fiscalyear_obj.find(
                 Transaction().context.get('company') or False, exception=False)
         if fiscalyear_id:
@@ -1591,9 +1597,10 @@ class OpenIncomeStatement(Wizard):
     }
 
     def _action_open(self, datas):
-        model_data_obj = self.pool.get('ir.model.data')
-        act_window_obj = self.pool.get('ir.action.act_window')
-        period_obj = self.pool.get('account.period')
+        pool = Pool()
+        model_data_obj = pool.get('ir.model.data')
+        act_window_obj = pool.get('ir.action.act_window')
+        period_obj = pool.get('account.period')
 
         start_period_ids = [0]
         if datas['form']['start_period']:
@@ -1724,14 +1731,15 @@ class CreateChartAccount(Wizard):
     }
 
     def _action_create_account(self, datas):
+        pool = Pool()
         account_type_template_obj = \
-                self.pool.get('account.account.type.template')
-        account_template_obj = self.pool.get('account.account.template')
-        tax_code_template_obj = self.pool.get('account.tax.code.template')
-        tax_template_obj = self.pool.get('account.tax.template')
-        tax_rule_template_obj = self.pool.get('account.tax.rule.template')
+                pool.get('account.account.type.template')
+        account_template_obj = pool.get('account.account.template')
+        tax_code_template_obj = pool.get('account.tax.code.template')
+        tax_template_obj = pool.get('account.tax.template')
+        tax_rule_template_obj = pool.get('account.tax.rule.template')
         tax_rule_line_template_obj = \
-                self.pool.get('account.tax.rule.line.template')
+                pool.get('account.tax.rule.line.template')
 
         with Transaction().set_context(language='en_US'):
             account_template = account_template_obj.browse(
@@ -1802,8 +1810,8 @@ class CreateChartAccount(Wizard):
         return {'company': datas['form']['company']}
 
     def _action_create_properties(self, datas):
-        property_obj = self.pool.get('ir.property')
-        model_field_obj = self.pool.get('ir.model.field')
+        property_obj = Pool().get('ir.property')
+        model_field_obj = Pool().get('ir.model.field')
 
         account_receivable_field_id = model_field_obj.search([
             ('model.model', '=', 'party.party'),
@@ -1816,14 +1824,13 @@ class CreateChartAccount(Wizard):
             ])
         with Transaction().set_user(0):
             property_obj.delete(property_ids)
-            if datas['form']['account_receivable']:
-                property_obj.create({
-                    'name': 'account_receivable',
-                    'field': account_receivable_field_id,
-                    'value': 'account.account,' + \
-                            str(datas['form']['account_receivable']),
-                    'company': datas['form']['company'],
-                    })
+            property_obj.create({
+                'name': 'account_receivable',
+                'field': account_receivable_field_id,
+                'value': 'account.account,' + \
+                        str(datas['form']['account_receivable']),
+                'company': datas['form']['company'],
+                })
 
         account_payable_field_id = model_field_obj.search([
             ('model.model', '=', 'party.party'),
@@ -1836,14 +1843,13 @@ class CreateChartAccount(Wizard):
             ])
         with Transaction().set_user(0):
             property_obj.delete(property_ids)
-            if datas['form']['account_payable']:
-                property_obj.create({
-                    'name': 'account_payable',
-                    'field': account_payable_field_id,
-                    'value': 'account.account,' + \
-                            str(datas['form']['account_payable']),
-                    'company': datas['form']['company'],
-                    })
+            property_obj.create({
+                'name': 'account_payable',
+                'field': account_payable_field_id,
+                'value': 'account.account,' + \
+                        str(datas['form']['account_payable']),
+                'company': datas['form']['company'],
+                })
         return {}
 
 CreateChartAccount()
@@ -1894,20 +1900,21 @@ class UpdateChartAccount(Wizard):
     }
 
     def _action_update_account(self, datas):
-        account_type_obj = self.pool.get('account.account.type')
+        pool = Pool()
+        account_type_obj = pool.get('account.account.type')
         account_type_template_obj = \
-                self.pool.get('account.account.type.template')
-        account_obj = self.pool.get('account.account')
-        account_template_obj = self.pool.get('account.account.template')
-        tax_code_obj = self.pool.get('account.tax.code')
-        tax_code_template_obj = self.pool.get('account.tax.code.template')
-        tax_obj = self.pool.get('account.tax')
-        tax_template_obj = self.pool.get('account.tax.template')
-        tax_rule_obj = self.pool.get('account.tax.rule')
-        tax_rule_template_obj = self.pool.get('account.tax.rule.template')
-        tax_rule_line_obj = self.pool.get('account.tax.rule.line')
+                pool.get('account.account.type.template')
+        account_obj = pool.get('account.account')
+        account_template_obj = pool.get('account.account.template')
+        tax_code_obj = pool.get('account.tax.code')
+        tax_code_template_obj = pool.get('account.tax.code.template')
+        tax_obj = pool.get('account.tax')
+        tax_template_obj = pool.get('account.tax.template')
+        tax_rule_obj = pool.get('account.tax.rule')
+        tax_rule_template_obj = pool.get('account.tax.rule.template')
+        tax_rule_line_obj = pool.get('account.tax.rule.line')
         tax_rule_line_template_obj = \
-                self.pool.get('account.tax.rule.line.template')
+                pool.get('account.tax.rule.line.template')
 
         account = account_obj.browse(datas['form']['account'])
 
@@ -2027,7 +2034,7 @@ class OpenThirdPartyBalanceInit(ModelView):
 
 
     def default_fiscalyear(self):
-        fiscalyear_obj = self.pool.get('account.fiscalyear')
+        fiscalyear_obj = Pool().get('account.fiscalyear')
         fiscalyear_id = fiscalyear_obj.find(
                 Transaction().context.get('company') or False, exception=False)
         if fiscalyear_id:
@@ -2073,10 +2080,11 @@ class ThirdPartyBalance(Report):
     _name = 'account.account.third_party_balance'
 
     def parse(self, report, objects, datas, localcontext):
-        party_obj = self.pool.get('party.party')
-        move_line_obj = self.pool.get('account.move.line')
-        company_obj = self.pool.get('company.company')
-        date_obj = self.pool.get('ir.date')
+        pool = Pool()
+        party_obj = pool.get('party.party')
+        move_line_obj = pool.get('account.move.line')
+        company_obj = pool.get('company.company')
+        date_obj = pool.get('ir.date')
         cursor = Transaction().cursor
 
         company = company_obj.browse(datas['form']['company'])
@@ -2146,7 +2154,7 @@ class OpenAgedBalanceInit(ModelView):
     posted = fields.Boolean('Posted Move', help='Show only posted move')
 
     def default_fiscalyear(self):
-        fiscalyear_obj = self.pool.get('account.fiscalyear')
+        fiscalyear_obj = Pool().get('account.fiscalyear')
         fiscalyear_id = fiscalyear_obj.find(
                 Transaction().context.get('company') or False, exception=False)
         if fiscalyear_id:
@@ -2222,10 +2230,11 @@ class AgedBalance(Report):
     _name = 'account.account.aged_balance'
 
     def parse(self, report, objects, datas, localcontext):
-        party_obj = self.pool.get('party.party')
-        move_line_obj = self.pool.get('account.move.line')
-        company_obj = self.pool.get('company.company')
-        date_obj = self.pool.get('ir.date')
+        pool = Pool()
+        party_obj = pool.get('party.party')
+        move_line_obj = pool.get('account.move.line')
+        company_obj = pool.get('company.company')
+        date_obj = pool.get('ir.date')
         cursor = Transaction().cursor
 
         company = company_obj.browse(datas['form']['company'])
