@@ -2,40 +2,43 @@
 #this repository contains the full copyright notices and license terms.
 from decimal import Decimal
 from trytond.model import ModelView, ModelSQL, fields
-from trytond.pyson import Get, Eval, And, Bool, Not, Or
+from trytond.pyson import Eval, Bool
 from trytond.transaction import Transaction
+from trytond.pool import Pool
 
 
 class Party(ModelSQL, ModelView):
     _name = 'party.party'
     account_payable = fields.Property(fields.Many2One('account.account',
-        'Account Payable', domain=[
-            ('kind', '=', 'payable'),
-            ('company', '=', Eval('company')),
-        ],
-        states={
-            'required': Bool(Eval('company')),
-            'invisible': Not(Bool(Eval('company'))),
-        }))
+            'Account Payable', domain=[
+                ('kind', '=', 'payable'),
+                ('company', '=', Eval('context', {}).get('company')),
+                ],
+            states={
+                'required': Bool(Eval('context', {}).get('company')),
+                'invisible': ~Eval('context', {}).get('company'),
+                }))
     account_receivable = fields.Property(fields.Many2One('account.account',
-        'Account Receivable', domain=[
-            ('kind', '=', 'receivable'),
-            ('company', '=', Eval('company')),
-        ],
-        states={
-            'required': Bool(Eval('company')),
-            'invisible': Not(Bool(Eval('company'))),
-        }))
+            'Account Receivable', domain=[
+                ('kind', '=', 'receivable'),
+                ('company', '=', Eval('context', {}).get('company', 0)),
+                ],
+            states={
+                'required': Bool(Eval('context', {}).get('company')),
+                'invisible': ~Eval('context', {}).get('company'),
+                }))
     customer_tax_rule = fields.Property(fields.Many2One('account.tax.rule',
-        'Customer Tax Rule', domain=[('company', '=', Eval('company'))],
-        states={
-            'invisible': Not(Bool(Eval('company'))),
-        }, help='Apply this rule on taxes when party is customer.'))
+            'Customer Tax Rule',
+            domain=[('company', '=', Eval('context', {}).get('company', 0))],
+            states={
+                'invisible': ~Eval('context', {}).get('company'),
+                }, help='Apply this rule on taxes when party is customer.'))
     supplier_tax_rule = fields.Property(fields.Many2One('account.tax.rule',
-        'Supplier Tax Rule', domain=[('company', '=', Eval('company'))],
-        states={
-            'invisible': Not(Bool(Eval('company'))),
-        }, help='Apply this rule on taxes when party is supplier.'))
+            'Supplier Tax Rule',
+            domain=[('company', '=', Eval('context', {}).get('company', 0))],
+            states={
+                'invisible': ~Eval('context', {}).get('company'),
+                }, help='Apply this rule on taxes when party is supplier.'))
     receivable = fields.Function(fields.Numeric('Receivable'),
             'get_receivable_payable', searcher='search_receivable_payable')
     payable = fields.Function(fields.Numeric('Payable'),
@@ -55,10 +58,11 @@ class Party(ModelSQL, ModelView):
             a dictionary as value with id as key
         '''
         res = {}
-        move_line_obj = self.pool.get('account.move.line')
-        company_obj = self.pool.get('company.company')
-        user_obj = self.pool.get('res.user')
-        date_obj = self.pool.get('ir.date')
+        pool = Pool()
+        move_line_obj = pool.get('account.move.line')
+        company_obj = pool.get('company.company')
+        user_obj = pool.get('res.user')
+        date_obj = pool.get('ir.date')
         cursor = Transaction().cursor
 
         for name in names:
@@ -123,10 +127,11 @@ class Party(ModelSQL, ModelView):
         return res
 
     def search_receivable_payable(self, name, clause):
-        move_line_obj = self.pool.get('account.move.line')
-        company_obj = self.pool.get('company.company')
-        user_obj = self.pool.get('res.user')
-        date_obj = self.pool.get('ir.date')
+        pool = Pool()
+        move_line_obj = pool.get('account.move.line')
+        company_obj = pool.get('company.company')
+        user_obj = pool.get('res.user')
+        date_obj = pool.get('ir.date')
         cursor = Transaction().cursor
 
         if name not in ('receivable', 'payable',
@@ -176,7 +181,7 @@ class Party(ModelSQL, ModelView):
                 'GROUP BY l.party '
                 'HAVING (SUM((COALESCE(l.debit, 0) - COALESCE(l.credit, 0))) ' \
                         + clause[1] + ' %s)',
-            [code] + today_value + [company_id] + [Decimal(clause[2] or 0)])
+                    [code] + today_value + [company_id] + [clause[2]])
         return [('id', 'in', [x[0] for x in cursor.fetchall()])]
 
 Party()
